pub struct InferenceWriter<O> { /* private fields */ }Expand description
Communication channel for an inference task, allowing the app to send outputs and errors back to the session.
Implementations
Sourceimpl<O> InferenceWriter<O>
impl<O> InferenceWriter<O>
pub fn with_observer(self, observer: Arc<dyn InferenceWriterObserver>) -> Self
Sourcepub fn write(&self, output: O) -> Result<(), InferenceWriterError>
pub fn write(&self, output: O) -> Result<(), InferenceWriterError>
Respond with an output item. This can be called multiple times to emit multiple items.